@@ -40,6 +40,7 @@
 #include <QShortcut>
 #include <QMenu>
 #include <QStyleFactory>
+#include <QImageReader>
 
 DWIDGET_USE_NAMESPACE
 
@@ -63,8 +64,11 @@ TopToolbar::TopToolbar(bool manager, QWidget *parent)
 {
     m_manager = manager;
     onThemeChanged(dApp->viewerTheme->getCurrentTheme());
+
+#ifndef LITE_DIV
     m_settingsWindow = new SettingsWindow();
     m_settingsWindow->hide();
+#endif
 
     initMenu();
     initWidgets();
@@ -181,7 +185,20 @@ void TopToolbar::initLeftContent()
     m_lLayout = new QHBoxLayout(w);
     m_lLayout->setContentsMargins(0, 0, 0, 0);
     m_lLayout->setSpacing(0);
+#ifdef LITE_DIV
+    QLabel *logo = new QLabel(this);
+    QImageReader ir(":/images/logo/resources/images/logo/deepin-image-viewer.svg");
 
+    ir.setScaledSize(QSize(22, 22) * devicePixelRatioF());
+
+    QPixmap logo_pix = QPixmap::fromImage(ir.read());
+
+    logo_pix.setDevicePixelRatio(this->devicePixelRatioF());
+    logo->setPixmap(logo_pix);
+    logo->setAlignment(Qt::AlignCenter);
+    m_layout->addSpacing(12);
+    m_layout->addWidget(logo, 1, Qt::AlignLeft);
+#endif
     m_layout->addWidget(w, 1, Qt::AlignLeft);
 }
 
@@ -231,27 +248,38 @@ void TopToolbar::initMenu()
 {
     m_menu = new QMenu(this);
     m_menu->setStyle(QStyleFactory::create("dlight"));
+
+#ifndef LITE_DIV
     if (m_manager)
     {
         QAction *acNA = m_menu->addAction(tr("New album"));
         connect(acNA, &QAction::triggered, this, &TopToolbar::onNewAlbum);
     }
+#endif
     QAction *acDT = m_menu->addAction(tr("Dark theme"));
 
     bool checkSelected =
             dApp->viewerTheme->getCurrentTheme() == ViewerThemeManager::Dark;
     acDT->setCheckable(checkSelected);
     acDT->setChecked(checkSelected);
+
+#ifndef LITE_DIV
     if (m_manager)
     {
         QAction *acS = m_menu->addAction(tr("Settings"));
         connect(acS, &QAction::triggered, this, &TopToolbar::onSetting);
     }
+#endif
+
     m_menu->addSeparator();
-    qApp->setProductIcon(QPixmap(":/resources/common/about_logo.png"));
+    qApp->setProductIcon(QIcon(":/images/logo/resources/images/logo/deepin-image-viewer.svg"));
+#ifdef LITE_DIV
+    qApp->setApplicationDescription(tr("Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance."));
+#else
     qApp->setApplicationDescription(QString("%1\n%2\n").arg(tr("Deepin Image Viewer is a fashion "
               "& smooth image manager.")).arg(tr("It is featured with image management, image viewing "
               "and basic image editing.")));
+#endif
     qApp->setApplicationAcknowledgementPage("https://www.deepin.org/"
                                             "acknowledgments/deepin-image-viewer/");
 
@@ -269,11 +297,15 @@ void TopToolbar::initMenu()
 //    connect(acA, &QAction::triggered, this, &TopToolbar::onAbout);
 //    connect(acE, &QAction::triggered, dApp, &Application::quit);
 
+#ifndef LITE_DIV
     QShortcut *scNA = new QShortcut(QKeySequence(newAlbumShortcut()), this);
+#endif
 
     QShortcut *scE = new QShortcut(QKeySequence("Ctrl+Q"), this);
     QShortcut *scViewShortcut = new QShortcut(QKeySequence("Ctrl+Shift+/"), this);
+#ifndef LITE_DIV
     connect(scNA, SIGNAL(activated()), this, SLOT(onNewAlbum()));
+#endif
     connect(scE, SIGNAL(activated()), dApp, SLOT(quit()));
     connect(scViewShortcut, SIGNAL(activated()), this, SLOT(onViewShortcut()));
 
@@ -288,11 +320,13 @@ void TopToolbar::initMenu()
         }
     });
 
+#ifndef LITE_DIV
     connect(dApp->setter, &ConfigSetter::valueChanged, this, [=] (const QString &group) {
         if (group == "SHORTCUTALBUM") {
             scNA->setKey(QKeySequence(newAlbumShortcut()));
         }
     });
+#endif
 }
 
 void TopToolbar::onViewShortcut() {
@@ -329,21 +363,12 @@ void TopToolbar::onHelp()
     }
 }
 
+#ifndef LITE_DIV
 void TopToolbar::onNewAlbum()
 {
     emit dApp->signalM->createAlbum();
 }
 
-void TopToolbar::onDeepColorMode() {
-    if (dApp->viewerTheme->getCurrentTheme() == ViewerThemeManager::Dark) {
-        dApp->viewerTheme->setCurrentTheme(
-                    ViewerThemeManager::Light);
-    } else {
-        dApp->viewerTheme->setCurrentTheme(
-                    ViewerThemeManager::Dark);
-    }
-}
-
 void TopToolbar::onSetting()
 {
     m_settingsWindow->move((width() - m_settingsWindow->width()) / 2 +
@@ -352,3 +377,14 @@ void TopToolbar::onSetting()
                            mapToGlobal(QPoint(0, 0)).y());
     m_settingsWindow->show();
 }
+#endif
+
+void TopToolbar::onDeepColorMode() {
+    if (dApp->viewerTheme->getCurrentTheme() == ViewerThemeManager::Dark) {
+        dApp->viewerTheme->setCurrentTheme(
+                    ViewerThemeManager::Light);
+    } else {
+        dApp->viewerTheme->setCurrentTheme(
+                    ViewerThemeManager::Dark);
+    }
+}
