@@ -261,8 +261,6 @@ void ImagesView::updateMenuContents()
     m_menu->addSeparator();
     /**************************************************************************/
     appendAction(IdCopy, tr("Copy"), ss("Copy"));
-    if (selectedCount == 1)
-        appendAction(IdCopyToClipboard, tr("Copy to clipboard"), ss("Copy to clipboard"));
     appendAction(IdMoveToTrash, tr("Delete"), ss("Throw to trash"));
     appendAction(IdRemoveFromAlbum, tr("Remove from album"), ss("Remove from album"));
     m_menu->addSeparator();
@@ -331,9 +329,6 @@ void ImagesView::onMenuItemClicked(QAction *action)
     case IdCopy:
         utils::base::copyImageToClipboard(paths);
         break;
-    case IdCopyToClipboard:
-        utils::base::copyOneImageToClipboard(path);
-        break;
     case IdMoveToTrash: {
         popupDelDialog(paths);
         break;
@@ -557,6 +552,7 @@ void  ImagesView::showPrintDialog(const QStringList &paths)
     QPrinter printer;
     QImage img;
     printer.setOutputFormat(QPrinter::PdfFormat);
+    printer.setColorMode(QPrinter::Color);
 
     QPrintDialog* printDialog = new QPrintDialog(&printer, this);
     PrintOptionsPage *optionsPage = new PrintOptionsPage;
