@@ -19,6 +19,7 @@
 #include "navigationwidget.h"
 #include "controller/divdbuscontroller.h"
 #include "controller/signalmanager.h"
+#include "controller/configsetter.h"
 #include "contents/imageinfowidget.h"
 #include "contents/ttmcontent.h"
 #include "contents/ttlcontent.h"
@@ -45,9 +46,7 @@
 #include <QtConcurrent>
 #include <QFileDialog>
 
-#include <QPrinter>
 #include <QPainter>
-#include <QPrintDialog>
 
 #include <DRecentManager>
 
@@ -168,8 +167,16 @@ void ViewPanel::initConnect()
         filter.append(utils::image::supportedImageFormats().join(" "));
         filter.append(')');
 
+        static QString cfgGroupName = QStringLiteral("General"), cfgLastOpenPath = QStringLiteral("LastOpenPath");
+        QString pictureFolder = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
+        QDir existChecker(pictureFolder);
+        if (!existChecker.exists()) {
+            pictureFolder = QDir::currentPath();
+        }
+        pictureFolder = dApp->setter->value(cfgGroupName, cfgLastOpenPath, pictureFolder).toString();
+
         const QStringList &image_list = QFileDialog::getOpenFileNames(this, tr("Open Image"),
-                                                                      QDir::currentPath(), filter, nullptr, QFileDialog::HideNameFilterDetails);
+                                                                      pictureFolder, filter, nullptr, QFileDialog::HideNameFilterDetails);
 
         if (image_list.isEmpty())
             return;
@@ -179,6 +186,9 @@ void ViewPanel::initConnect()
         vinfo.path = image_list.first();
         vinfo.paths = image_list;
 
+        QFileInfo firstFileInfo(vinfo.path);
+        dApp->setter->setValue(cfgGroupName, cfgLastOpenPath, firstFileInfo.path());
+
         onViewImage(vinfo);
     });
 #endif
@@ -491,6 +501,12 @@ void ViewPanel::timerEvent(QTimerEvent *e)
     ModulePanel::timerEvent(e);
 }
 
+void ViewPanel::wheelEvent(QWheelEvent *e)
+{
+    if (m_viewB && !m_viewB->path().isEmpty())
+        qApp->sendEvent(m_viewB->viewport(), e);
+}
+
 void ViewPanel::dropEvent(QDropEvent *event)
 {
     QList<QUrl> urls = event->mimeData()->urls();
