@@ -245,10 +245,6 @@
         <source>Copy</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"></translation>
@@ -326,10 +322,6 @@
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation type="unfinished"></translation>
@@ -398,6 +390,10 @@
         <source>Lens model</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1007,10 +1003,6 @@
         <source>Copy</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"></translation>
