@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>ኮፒ</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>አይነት</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>ፎቶ የ ተነሳበት ቀን</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>የ ተሻሻለበት ቀን</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>የ ሌንስ አይነት</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>ኮፒ</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
