@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>نسخ</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>نسخ إلى الحافظة </translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>حذف من اﻷلبوم</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>النوع</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>تاريخ التصوير</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>تاريخ التعديل</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>طراز العدسة</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>نسخ</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>نسخ إلى الحافظة </translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>حذف من اﻷلبوم</translation>
