@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copiar al cartafueyu</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Desaniciar del álbum</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Triba</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Data de fechura</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data de modificación</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Modelu de lente</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copiar al cartafueyu</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Desaniciar del álbum</translation>
