@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Копиране</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Копиране в системния буфер</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Премахване от албума</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Тип</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Дата за заснемане</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Дата на промяна</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Модел на обектива</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Дата на заснемане</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Копиране</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Копиране в системния буфер</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Премахване от албума</translation>
