@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copia al porta-retalls</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Elimina de l&apos;àlbum</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Tipus</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Data de fotografia</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data de modificació</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Model de la lent</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Data de captura</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copia al porta-retalls</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Elimina de l&apos;àlbum</translation>
