@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Kopiér</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopiér til udklipsholder</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Fjern fra album</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Type</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Fotograferingsdato</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Ændringsdato</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Linsemodel</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Optagelsesdato</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Kopiér</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopiér til udklipsholder</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Fjern fra album</translation>
