@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Αντιγραφή</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Αντιγραφή στο πρόχειρο</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>αφαίρεση από το άλμπουμ</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Τύπος</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Ημερομηνία φωτογράφησης</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Ημερομηνία επεξεργασίας</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Μοντέλο φακού</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"/>
