@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copiar al portapapeles</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eliminar del álbum</translation>
@@ -297,7 +293,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Borrar</translation>
     </message>
 </context>
 <context>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Tipo</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Fecha de la foto</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Fecha modificada</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Modelo de lente</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Fecha de la foto</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -616,7 +612,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Borrar</translation>
     </message>
 </context>
 <context>
@@ -766,31 +762,31 @@
     </message>
     <message>
         <source>1:1 Size</source>
-        <translation type="unfinished"/>
+        <translation>1:1 Tamaño</translation>
     </message>
     <message>
         <source>Fit to window</source>
-        <translation type="unfinished"/>
+        <translation>Ajustar a Ventana</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Gire hacia la izquierda</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Gire hacia la derecha</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>No Favorito</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>Favorito</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Borrar</translation>
     </message>
 </context>
 <context>
@@ -899,7 +895,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Borrar</translation>
     </message>
 </context>
 <context>
@@ -968,7 +964,7 @@
     </message>
     <message>
         <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
-        <translation type="unfinished"/>
+        <translation>El visor de imágenes deepin es un gestor de imágenes rápido y moderno.</translation>
     </message>
 </context>
 <context>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copiar a Portapapeles</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover del álbum</translation>
@@ -1051,7 +1043,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Borrar</translation>
     </message>
     <message>
         <source>Open Image</source>
