@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>העתקה</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>העתקה ללוח הגזירים</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>הסרה מהאלבום</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>סוג</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>מועד הצילום</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>מועד השינוי</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>דגם העדשה</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"/>
