@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Kopiraj</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopiraj u međuspremnik</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Ukloni iz albuma</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Vrsta</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Nadnevak slikanja</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Nadnevak izmjene</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Model leća</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Kopiraj</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopiraj u međuspremnik</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Ukloni iz albuma</translation>
