@@ -218,7 +218,7 @@
     <name>ImageView</name>
     <message>
         <source>This file contains multiple pages, please use Evince to view all pages.</source>
-        <translation>Ez a fájl több oldalt tartalmaz, kérem használja az Evince-t az össze oldal megtekintéséhez.</translation>
+        <translation>Ez a fájl több oldalt tartalmaz, kérlek használd az Evince-t az összes oldal megtekintéséhez.</translation>
     </message>
 </context>
 <context>
@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Másolás</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Másolás vágólapra</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eltávolítás az albumból</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Típus</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Fotózás dátuma</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Módosítás dátuma</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Lencse minta</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Másolás</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Másolás vágólapra</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Törlés az albumból</translation>
