@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copia negli appunti</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Rimuovi dall&apos;album</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Tipo</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Data scatto</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data modifica</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Modello lente</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Data individuata</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1006,10 +1002,6 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Copia negli appunti</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Rimuovi dall&apos;album</translation>
