@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Kopijuoti</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopijuoti į iškarpinę</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Šalinti iš albumo</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Tipas</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Fotografavimo data</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Keitimo data</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Objektyvo modelis</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Fotografavimo data</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Kopijuoti</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopijuoti į iškarpinę</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Šalinti iš albumo</translation>
