@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Salin</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Salin ke papan keratan</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Buang dari album</translation>
@@ -324,17 +320,13 @@
         <source>Type</source>
         <translation>Jenis</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Tarikh ditangkap</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Tarikh diubahsuai</translation>
     </message>
     <message>
         <source>Dimension</source>
-        <translation type="unfinished"/>
+        <translation>Dimensi</translation>
     </message>
     <message>
         <source>File size</source>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Model kanta</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Tarikh ditangkap</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -444,7 +440,7 @@
     <name>PrintPreviewDialog</name>
     <message>
         <source>Image Settings</source>
-        <translation type="unfinished"/>
+        <translation>Tetapan Imej</translation>
     </message>
 </context>
 <context>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Salin</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Salin ke papan keratan</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Buang dari album</translation>
