@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Kopiuj</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopiuj do schowka</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Usuń z albumu</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Rodzaj</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Data fotografowania</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Data modyfikacji</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Model obiektywu</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Data rejestracji</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Kopiuj</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopiuj do schowka</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Usuń z albumu</translation>
