@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Копировать в буфер обмена</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Удалить из альбома</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Тип</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Дата снимка</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Дата изменения</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Модель линзы</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Дата захвата</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Копировать в буфер обмена</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Удалить из альбома</translation>
