@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Kopírovanie</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Skopírovať do schránky</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Odstrániť z albumu</translation>
@@ -297,7 +293,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Odstrániť</translation>
     </message>
 </context>
 <context>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Typ</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Dátum fotografovania</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Dátum úpravy</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Model objektívu</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Dátum fotografovania</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -444,7 +440,7 @@
     <name>PrintPreviewDialog</name>
     <message>
         <source>Image Settings</source>
-        <translation type="unfinished"/>
+        <translation>Nastavenia obrázku</translation>
     </message>
 </context>
 <context>
@@ -616,7 +612,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Odstrániť</translation>
     </message>
 </context>
 <context>
@@ -790,7 +786,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Odstrániť</translation>
     </message>
 </context>
 <context>
@@ -899,7 +895,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Odstrániť</translation>
     </message>
 </context>
 <context>
@@ -968,7 +964,7 @@
     </message>
     <message>
         <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
-        <translation type="unfinished"/>
+        <translation>Deepin Prehliadač obrázkov je módny a plynulý manažér obrázkov.</translation>
     </message>
 </context>
 <context>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Kopírovať</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Skopírovať do schránky</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Odstrániť z albumu</translation>
@@ -1051,7 +1043,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Odstrániť</translation>
     </message>
     <message>
         <source>Open Image</source>
