@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Копирај</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Копирај у бележницу</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Уклони из албума</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>Тип</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Датум сликања</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Измењено</translation>
@@ -346,15 +338,15 @@
     </message>
     <message>
         <source>Exposure mode</source>
-        <translation>Режим експозиције</translation>
+        <translation>Режим експоз...</translation>
     </message>
     <message>
         <source>Exposure program</source>
-        <translation>Програм експозиције</translation>
+        <translation>Програм експоз...</translation>
     </message>
     <message>
         <source>Exposure time</source>
-        <translation>Трајање експозиције</translation>
+        <translation>Трајање експоз...</translation>
     </message>
     <message>
         <source>Flash</source>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Модел сочива</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Датум снимања</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -470,7 +466,7 @@
     <name>ScanPathsDialog</name>
     <message>
         <source>Select Directory</source>
-        <translation>Одабери директоријум</translation>
+        <translation>Изабери директоријум</translation>
     </message>
     <message>
         <source>This directory is disabled to sync</source>
@@ -642,7 +638,7 @@
     </message>
     <message>
         <source>Restore Defaults</source>
-        <translation>Врати подразумевано</translation>
+        <translation>Врати Подразумевано</translation>
     </message>
 </context>
 <context>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>Копирај</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Копирај у бележницу</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Уклони из албума</translation>
