@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>Kopiera</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>Kopiera till urklipp</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Radera från album</translation>
@@ -297,7 +293,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Radera</translation>
     </message>
 </context>
 <context>
@@ -324,17 +320,13 @@
         <source>Type</source>
         <translation>Typ</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>Fotodatum</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Ändringsdatum</translation>
     </message>
     <message>
         <source>Dimension</source>
-        <translation type="unfinished"/>
+        <translation>Dimensioner</translation>
     </message>
     <message>
         <source>File size</source>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>Linsmodell</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"/>
