@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>复制</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>复制到剪贴板</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>从相册中移除</translation>
@@ -324,10 +320,6 @@
         <source>Type</source>
         <translation>图片类型</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>拍摄时间</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>修改时间</translation>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>镜头型号</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>拍摄时间</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>复制</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>复制到剪贴板</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>从相册中移除</translation>
