@@ -243,10 +243,6 @@
         <source>Copy</source>
         <translation>複製</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>複製到剪貼簿</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>從相簿移除</translation>
@@ -324,17 +320,13 @@
         <source>Type</source>
         <translation>類型</translation>
     </message>
-    <message>
-        <source>Date photoed</source>
-        <translation>拍攝時間</translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>修改時間</translation>
     </message>
     <message>
         <source>Dimension</source>
-        <translation type="unfinished"/>
+        <translation>尺寸</translation>
     </message>
     <message>
         <source>File size</source>
@@ -396,6 +388,10 @@
         <source>Lens model</source>
         <translation>鏡頭型號</translation>
     </message>
+    <message>
+        <source>Date captured</source>
+        <translation>已擷取日期</translation>
+    </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
@@ -444,7 +440,7 @@
     <name>PrintPreviewDialog</name>
     <message>
         <source>Image Settings</source>
-        <translation type="unfinished"/>
+        <translation>圖片設定</translation>
     </message>
 </context>
 <context>
@@ -1005,10 +1001,6 @@
         <source>Copy</source>
         <translation>複製</translation>
     </message>
-    <message>
-        <source>Copy to clipboard</source>
-        <translation>複製到剪貼簿</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>從相簿移除</translation>
