@@ -11,7 +11,7 @@ class PrintHelper : public QObject
 public:
     PrintHelper(QObject *parent = nullptr);
 
-    static void showPrintDialog(const QStringList &paths);
+    static void showPrintDialog(const QStringList &paths, QWidget *parent = nullptr);
 
     static QSize adjustSize(PrintOptionsPage* optionsPage, QImage img, int resolution, const QSize & viewportSize);
     static QPoint adjustPosition(PrintOptionsPage* optionsPage, const QSize& imageSize, const QSize & viewportSize);
