@@ -1,7 +1,7 @@
 #ifndef PRINTOPTIONSPAGE_H
 #define PRINTOPTIONSPAGE_H
 
-#include <QWidget>
+#include <QDialog>
 #include <QRadioButton>
 #include <QDoubleSpinBox>
 #include <QButtonGroup>
@@ -9,7 +9,7 @@
 #include <QCheckBox>
 #include <QSettings>
 
-class PrintOptionsPage : public QWidget
+class PrintOptionsPage : public QDialog
 {
     Q_OBJECT
 
@@ -36,6 +36,9 @@ public:
     double scaleHeight();
     Qt::Alignment alignment();
 
+signals:
+    void valueChanged();
+
 private:
     void init();
     void updateStatus();
